Extract: Extract or replace parts of a free group object

ExtractR Documentation

Extract or replace parts of a free group object

Description

Extract or replace subsets of free objects

Usage

## S3 method for class 'free'
x[...]
## S3 replacement method for class 'free'
x[index] <-  value

Arguments

x

Object of class free

index

elements to extract or replace

value

replacement value

...

Elements to extract

Details

These methods (should) work as expected: an object of class free is a list but standard extraction techniques should work.

Note

Extraction by NA is not implemented.

Examples


(x <- rfree(20,8,8))

x[5:6]
x[1:2]  <- -x[11:12]

x[1:5] <- keep(x[1:5],1:3)


freegroup documentation built on July 15, 2026, 5:07 p.m.