| dot-class | R Documentation |
The dot object is defined in the freealg package, and
imported here, so that idiom like .[x,y] returns the
commutator, that is, x^-1 y^-1 xy.
The dot object is generated by running script inst/dot.Rmd,
which includes some further discussion and technical documentation,
and creates file dot.rda which resides in the data/
directory.
## S4 method for signature 'dot,ANY,ANY'
x[i, j, drop]
## S4 method for signature 'dot,free,ANY,ANY'
x[i, j, drop]
x |
Object of any class |
i, j |
elements to commute |
drop |
Boolean, indicates whether to drop attributes |
Always returns an object of the same class as xy.
Robin K. S. Hankin
.[as.free("x"), as.free("y")]
.[abc(1:6), "z"]
x <- rfree()
y <- rfree()
z <- rfree()
.[x, y] == -x-y+x+y # should be TRUE
abelianize(.[x, y])
## Jacobi identity _not_ satisfied with this definition:
is.id(.[x, .[y, z]] + .[y, .[z, x]] + .[z, .[x, y]])
## But the Hall-Witt identity is:
all(is.id(.[.[x, -y], z]^y + .[.[y, -z], x]^z + .[.[z, -x], y]^x))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.